import React, { useState, useEffect } from 'react';
import { Alert, Spin } from 'antd';
import { ExclamationCircleOutlined, LoadingOutlined } from '@ant-design/icons';
import { Component } from '../types/component';
import { API_URL } from '../config';

interface ComponentErrorDisplayProps {
  componentId: number;
}

export const ComponentErrorDisplay: React.FC<ComponentErrorDisplayProps> = ({ componentId }) => {
  const [component, setComponent] = useState<Component | null>(null);
  const [isLoading, setIsLoading] = useState(false);

  const fetchComponent = async () => {
    setIsLoading(true);
    try {
      const response = await fetch(`${API_URL}/components/${componentId}`);
      if (response.ok) {
        const data = await response.json();
        setComponent(data);
      }
    } catch (error) {
      console.error('Error fetching component:', error);
    } finally {
      setIsLoading(false);
    }
  };

  useEffect(() => {
    if (componentId) {
      fetchComponent();
    }
  }, [componentId]);

  if (isLoading) {
    return <Spin indicator={<LoadingOutlined style={{ fontSize: 14 }} spin />} />;
  }

  if (!component || !component.error_msg) {
    return null;
  }

  return (
    <Alert
      message="Component Validation Issues"
      description={component.error_msg}
      type="warning"
      icon={<ExclamationCircleOutlined />}
      showIcon
      style={{ marginBottom: 16 }}
      closable
    />
  );
};
