import React from 'react';
import { Tag, Tooltip } from 'antd';
import { 
  LoadingOutlined, 
  CheckCircleOutlined, 
  ExclamationCircleOutlined,
  StopOutlined,
  RocketOutlined
} from '@ant-design/icons';
import { PreviewStatus } from '../types/preview';

interface PreviewStatusBadgeProps {
  status: PreviewStatus;
  errorMessage?: string;
  size?: 'small' | 'default';
}

export const PreviewStatusBadge: React.FC<PreviewStatusBadgeProps> = ({
  status,
  errorMessage,
  size = 'default'
}) => {
  const getStatusConfig = (status: PreviewStatus) => {
    const configs = {
      building: {
        color: 'processing',
        icon: <LoadingOutlined spin />,
        text: 'BUILDING',
        tooltip: 'Building Docker images from component repositories'
      },
      deploying: {
        color: 'processing',
        icon: <RocketOutlined />,
        text: 'DEPLOYING',
        tooltip: 'Deploying containers and starting services'
      },
      running: {
        color: 'success',
        icon: <CheckCircleOutlined />,
        text: 'RUNNING',
        tooltip: 'Preview is live and accessible'
      },
      failed: {
        color: 'error',
        icon: <ExclamationCircleOutlined />,
        text: 'FAILED',
        tooltip: 'Error occurred during build or deployment'
      },
      stopped: {
        color: 'default',
        icon: <StopOutlined />,
        text: 'STOPPED',
        tooltip: 'Preview was stopped or expired'
      }
    };
    
    return configs[status] || configs.stopped;
  };

  const config = getStatusConfig(status);

  // Create detailed tooltip content
  const tooltipContent = (
    <div>
      <div style={{ fontWeight: 'bold', marginBottom: errorMessage ? 4 : 0 }}>
        {config.tooltip}
      </div>
      {errorMessage && (
        <div style={{ color: '#ff7875', fontSize: '12px', maxWidth: '300px' }}>
          Error: {errorMessage}
        </div>
      )}
    </div>
  );

  return (
    <Tooltip title={tooltipContent} placement="top">
      <Tag 
        color={config.color} 
        icon={config.icon}
        style={{ fontSize: size === 'small' ? '12px' : '14px' }}
      >
        {config.text}
      </Tag>
    </Tooltip>
  );
};
