import { useEffect } from 'react';
import { UseShowReturnType } from '@refinedev/core';
import { shouldPollComponentStatus, getPollingInterval } from '../utils/componentPolling';
import { Component } from '../types/component';

/**
 * Custom hook for polling component status during async operations
 */
export const useComponentStatusPolling = (queryResult: UseShowReturnType['queryResult']) => {
  const component = queryResult?.data?.data as Component;
  
  useEffect(() => {
    if (!component?.status) return;
    
    if (shouldPollComponentStatus(component.status)) {
      const interval = getPollingInterval(component.status);
      
      const pollTimer = setInterval(() => {
        queryResult.refetch();
      }, interval);
      
      return () => clearInterval(pollTimer);
    }
  }, [component?.status, queryResult]);
  
  return {
    isPolling: shouldPollComponentStatus(component?.status),
    component
  };
};
