import React from 'react';
import { Create, useForm, useSelect } from "@refinedev/antd";
import { Form, Input, Select, Card } from 'antd';
import { AppFormData } from '../../types/app';

export const AppCreate = () => {
    const { formProps, saveButtonProps } = useForm<AppFormData>();

    const { selectProps: componentSelectProps } = useSelect({
        resource: "components",
        optionLabel: "name",
        optionValue: "id",
    });

    return (
        <Create saveButtonProps={saveButtonProps}>
            <Form {...formProps} layout="vertical">
                <Card title="App Information">
                    <Form.Item
                        label="Name"
                        name="name"
                        rules={[{ required: true, message: 'Please enter an app name' }]}
                    >
                        <Input placeholder="Enter app name" />
                    </Form.Item>

                    <Form.Item
                        label="Version"
                        name="version"
                        rules={[{ required: true, message: 'Please enter the version' }]}
                        initialValue="1.0.0"
                    >
                        <Input placeholder="E.g., 1.0.0" />
                    </Form.Item>

                    <Form.Item
                        label="Components"
                        name="components"
                        rules={[{ required: true, message: 'Please select at least one component' }]}
                    >
                        <Select
                            {...componentSelectProps}
                            mode="multiple"
                            placeholder="Select components to include in this app"
                            showSearch
                            filterOption={(input, option) =>
                                String(option?.label ?? '').toLowerCase().includes(input.toLowerCase())
                            }
                        />
                    </Form.Item>
                </Card>
            </Form>
        </Create>
    );
};
