import {
    DeleteButton,
    EditButton,
    List,
    ShowButton,
    useTable,
} from "@refinedev/antd";
import type { BaseRecord } from "@refinedev/core";
import { Space, Table, Tag, Button, Tooltip, Typography } from "antd";
import { PlusOutlined, ApiOutlined } from '@ant-design/icons';
import { PreviewStatusColumn } from "../../components";

const { Title } = Typography;

export const AppList = () => {
    const { tableProps } = useTable({
        syncWithLocation: true,
    });

    return (
        <>
            <div style={{ display: "flex", justifyContent: "space-between", alignItems: "center", marginBottom: 16 }}>
                <Title level={4}>Deployment Apps</Title>
                <Button type="primary" icon={<PlusOutlined />} href="/apps/create">
                    Create New App
                </Button>
            </div>
            <List>
                <Table {...tableProps} rowKey="id">
                    <Table.Column dataIndex="name" title="Name" />
                    <Table.Column dataIndex="version" title="Version" 
                        render={(value) => <Tag color="blue">{value}</Tag>}
                    />
                    <Table.Column
                        title="Components"
                        render={(_, record: BaseRecord) => (
                            <Tag color="green">
                                {record?.components?.length || 0} Components
                            </Tag>
                        )}
                    />
                    <Table.Column
                        title="Preview"
                        render={(_, record: BaseRecord) => (
                            record.id ? (
                                <PreviewStatusColumn 
                                    appId={Number(record.id)} 
                                    appName={record.name || 'Unknown'} 
                                />
                            ) : null
                        )}
                    />
                    <Table.Column
                        title="Actions"
                        dataIndex="actions"
                        render={(_, record: BaseRecord) => (
                            <Space>
                                <Tooltip title="Deploy">
                                    <Button
                                        type="primary"
                                        size="small"
                                        icon={<ApiOutlined />}
                                        href={`/deployments/create?appId=${record.id}`}
                                    />
                                </Tooltip>
                                <ShowButton hideText size="small" recordItemId={record.id} />
                                <EditButton hideText size="small" recordItemId={record.id} />
                                <DeleteButton hideText size="small" recordItemId={record.id} />
                            </Space>
                        )}
                    />
                </Table>
            </List>
        </>
    );
}
// ...existing code...
