import {
  CreateButton,
  DeleteButton,
  EditButton,
  List,
  ShowButton,
  useTable,
} from "@refinedev/antd";
import type { BaseRecord } from "@refinedev/core";
import { Space, Table, Tag } from "antd";

export const ClientList = () => {
  const { tableProps } = useTable({
    syncWithLocation: true,
  });

  return (
    <List 
      headerButtons={[
        <CreateButton key="create" />
      ]}
    >
      <Table {...tableProps} rowKey="id">
        <Table.Column dataIndex="name" title="Client Name" />
        <Table.Column dataIndex="contactEmail" title="Contact Email" />
        <Table.Column dataIndex="organization" title="Organization" />
        <Table.Column
          dataIndex="createdAt"
          title="Created At"
          render={(value) => {
            return new Date(value).toLocaleDateString();
          }}
        />
        <Table.Column
          title="Actions"
          dataIndex="actions"
          render={(_, record: BaseRecord) => (
            <Space>
              <ShowButton hideText size="small" recordItemId={record.id} />
              <EditButton hideText size="small" recordItemId={record.id} />
              <DeleteButton hideText size="small" recordItemId={record.id} />
            </Space>
          )}
        />
      </Table>
    </List>
  );
};