import React from 'react';
import { Create, useForm } from "@refinedev/antd";
import { Form, Input, Select, Card, Alert } from 'antd';
import { ComponentFormData } from '../../types/component';

export const ComponentCreate = () => {
  const { formProps, saveButtonProps } = useForm<ComponentFormData>();
  
  return (
    <Create saveButtonProps={saveButtonProps}>
      <Form {...formProps} layout="vertical">
        <Alert
          message="Component Validation"
          description="After creating your component, an asynchronous validation process will start to verify your repository and configuration. You can monitor the validation status on the component details page."
          type="info"
          showIcon
          style={{ marginBottom: 16 }}
        />
        <Card title="Component Information">
          <Form.Item
            label="Name"
            name="name"
            rules={[{ required: true, message: 'Please enter a component name' }]}
          >
            <Input placeholder="Enter component name" />
          </Form.Item>
          
          <Form.Item
            label="Description"
            name="description"
          >
            <Input.TextArea 
              placeholder="Enter component description (optional)" 
              rows={3}
            />
          </Form.Item>
          
          <Form.Item
            label="Type"
            name="type"
            rules={[{ required: true, message: 'Please select a component type' }]}
          >
            <Select placeholder="Select component type">
              <Select.Option value="frontend">Frontend</Select.Option>
              <Select.Option value="backend">Backend</Select.Option>
              <Select.Option value="api">API</Select.Option>
              <Select.Option value="database">Database</Select.Option>
              <Select.Option value="microservice">Microservice</Select.Option>
            </Select>
          </Form.Item>

          <Form.Item
            label="Git Repository URL"
            name="repository"
            rules={[
              { required: true, message: 'Please enter the Git repository URL' },
              { type: 'url', message: 'Please enter a valid URL' }
            ]}
          >
            <Input placeholder="https://github.com/username/repo" />
          </Form.Item>

          <Form.Item
            label="Branch"
            name="branch"
            initialValue="main"
          >
            <Input placeholder="Enter branch name (default: main)"/>
          </Form.Item>

          <Form.Item
            label="Configuration"
            name="config"
            initialValue="{}"
          >
            <Input.TextArea 
              placeholder="Enter JSON configuration (optional)" 
              rows={4}
            />
          </Form.Item>
        </Card>
      </Form>
    </Create>
  );
};
