import React from 'react';
import { List, useTable, DateField } from "@refinedev/antd";
import { useParams, useNavigate } from 'react-router';
import { Table, Tag, Typography, Card, Button } from 'antd';
import { ArrowLeftOutlined, LinkOutlined } from '@ant-design/icons';

const { Title, Text } = Typography;

export const ComponentDeployments = () => {
  const { id } = useParams();
  const navigate = useNavigate();
  
  const { tableProps } = useTable({
    resource: `components/${id}/deployments`,
    syncWithLocation: true,
  });

  const getStatusColor = (status: string) => {
    const colorMap: Record<string, string> = {
      running: 'success',
      stopped: 'default',
      failed: 'error',
      deploying: 'processing',
    };
    return colorMap[status] || 'default';
  };

  const getEnvironmentColor = (environment: string) => {
    const colorMap: Record<string, string> = {
      production: 'red',
      staging: 'orange',
      development: 'blue',
      testing: 'purple',
    };
    return colorMap[environment] || 'default';
  };

  return (
    <>
      <div style={{ display: "flex", alignItems: "center", marginBottom: 16 }}>
        <Button 
          icon={<ArrowLeftOutlined />} 
          onClick={() => navigate(`/components/show/${id}`)}
          style={{ marginRight: 16 }}
        >
          Back to Component
        </Button>
        <Title level={4} style={{ margin: 0 }}>Component Deployments</Title>
      </div>

      <Card>
        <Text type="secondary" style={{ marginBottom: 16, display: 'block' }}>
          All deployments that include this component
        </Text>
        
        <List>
          <Table {...tableProps} rowKey="id">
            <Table.Column dataIndex="name" title="Deployment Name" />
            <Table.Column 
              dataIndex="description" 
              title="Description"
              render={(value) => value || <span style={{ color: '#999' }}>No description</span>}
            />
            <Table.Column 
              dataIndex="environment" 
              title="Environment"
              render={(value) => (
                <Tag color={getEnvironmentColor(value)}>
                  {value?.toUpperCase()}
                </Tag>
              )}
            />
            <Table.Column 
              dataIndex="status" 
              title="Status"
              render={(value) => (
                <Tag color={getStatusColor(value)}>
                  {value?.toUpperCase()}
                </Tag>
              )}
            />
            <Table.Column 
              dataIndex="url" 
              title="URL"
              render={(value) => (
                value ? (
                  <a href={value} target="_blank" rel="noopener noreferrer">
                    <LinkOutlined /> Access
                  </a>
                ) : (
                  <span style={{ color: '#999' }}>No URL</span>
                )
              )}
            />
            <Table.Column 
              dataIndex="deployed_at" 
              title="Deployed At"
              render={(value) => (
                value ? <DateField value={value} /> : <span style={{ color: '#999' }}>Not deployed</span>
              )}
            />
            <Table.Column 
              dataIndex="created_at" 
              title="Created"
              render={(value) => <DateField value={value} />}
            />
          </Table>
        </List>
      </Card>
    </>
  );
};
