import {
  DeleteButton,
  EditButton,
  List,
  ShowButton,
  useTable,
  TagField,
} from "@refinedev/antd";
import type { BaseRecord } from "@refinedev/core";
import { Space, Table, Tag } from "antd";

export const DeploymentList = () => {
  const { tableProps } = useTable({
    syncWithLocation: true,
  });

  return (
    <List>
      <Table {...tableProps} rowKey="id">
        <Table.Column
          dataIndex="name"
          title={"Name"}
        />
        <Table.Column
          title={"App"}
          render={(_, record: BaseRecord) => (
            <a href={`/apps/show/${record.app_id}`}>
              App {record.app_id}
            </a>
          )}
        />
        <Table.Column
          dataIndex="environment"
          title={"Environment"}
          render={(value) => {
            const colorMap: Record<string, string> = {
              dev: 'green',
              preprod: 'orange',
              prod: 'red',
            };
            return <Tag color={colorMap[value] || 'default'}>{value.toUpperCase()}</Tag>;
          }}
        />
        <Table.Column 
          dataIndex="version" 
          title={"Version"}
          render={(value) => <Tag color="blue">{value}</Tag>}
        />
        <Table.Column
          title={"Client"}
          render={(_, record: BaseRecord) => (
            <a href={`/clients/show/${record.client_id}`}>
              Client {record.client_id}
            </a>
          )}
        />
        <Table.Column
          title={"Actions"}
          dataIndex="actions"
          render={(_, record: BaseRecord) => (
            <Space>
              <ShowButton hideText size="small" recordItemId={record.id} />
              <EditButton hideText size="small" recordItemId={record.id} />
              <DeleteButton hideText size="small" recordItemId={record.id} />
            </Space>
          )}
        />
      </Table>
    </List>
  );
};