import { Show, TextField, TagField, DateField } from "@refinedev/antd";
import { useOne, useShow } from "@refinedev/core";
import { Typography, Card, Descriptions, Badge, Divider, Progress, Row, Col } from "antd";
import { CheckCircleOutlined, WarningOutlined } from '@ant-design/icons';

const { Title } = Typography;

export const DeploymentShow = () => {
  const { queryResult } = useShow({});
  const { data, isLoading } = queryResult;
  const record = data?.data;

  const { data: clientData, isLoading: clientIsLoading } = useOne({
    resource: "clients",
    id: record?.clientId || "",
    queryOptions: {
      enabled: !!record,
    },
  });

  const { data: appData, isLoading: appIsLoading } = useOne({
    resource: "apps",
    id: record?.appId || "",
    queryOptions: {
      enabled: !!record,
    },
  });

  return (
    <Show isLoading={isLoading}>
      <Title level={5}>Deployment Information</Title>

      <Card>
        <Descriptions bordered column={2}>
          <Descriptions.Item label="Deployment Name">{record?.name}</Descriptions.Item>
          <Descriptions.Item label="Status">
            <Badge
              status={record?.status === "active" ? "success" : record?.status === "pending" ? "processing" : "error"}
              text={record?.status}
            />
          </Descriptions.Item>
          <Descriptions.Item label="Client">
            {clientIsLoading ? "Loading..." : clientData?.data?.name}
          </Descriptions.Item>
          <Descriptions.Item label="App">
            {appIsLoading ? "Loading..." : appData?.data?.name}
          </Descriptions.Item>
          <Descriptions.Item label="Version">{record?.version}</Descriptions.Item>
          <Descriptions.Item label="Environment">{record?.environment}</Descriptions.Item>
          <Descriptions.Item label="Deployed On">
            <DateField value={record?.deploymentDate} format="YYYY-MM-DD HH:mm" />
          </Descriptions.Item>
          <Descriptions.Item label="Last Updated">
            <DateField value={record?.updatedAt} format="YYYY-MM-DD HH:mm" />
          </Descriptions.Item>
        </Descriptions>
      </Card>

      <Divider />

      <Row gutter={24}>
        <Col span={12}>
          <Card title="Health Status">
            <div style={{ display: 'flex', alignItems: 'center' }}>
              {record?.healthStatus === "healthy" ? (
                <CheckCircleOutlined style={{ color: 'green', fontSize: '24px', marginRight: '10px' }} />
              ) : (
                <WarningOutlined style={{ color: 'red', fontSize: '24px', marginRight: '10px' }} />
              )}
              <span style={{ fontSize: '16px' }}>
                {record?.healthStatus === "healthy" ? "All systems operational" : "Issues detected"}
              </span>
            </div>
          </Card>
        </Col>
        <Col span={12}>
          <Card title="Resource Utilization">
            <div>
              <div style={{ marginBottom: '10px' }}>CPU</div>
              <Progress percent={record?.cpuUsage || 0} size="small" />

              <div style={{ marginBottom: '10px', marginTop: '15px' }}>Memory</div>
              <Progress percent={record?.memoryUsage || 0} size="small" />

              <div style={{ marginBottom: '10px', marginTop: '15px' }}>Storage</div>
              <Progress percent={record?.storageUsage || 0} size="small" />
            </div>
          </Card>
        </Col>
      </Row>
    </Show>
  );
};