import { AuthPage } from "@refinedev/antd";
import { Typography, Alert, Space } from "antd";
import { useState } from "react";
import { useForgotPassword } from "@refinedev/core";

const { Title, Text } = Typography;

export const ForgotPassword = () => {
  const [error, setError] = useState<string | null>(null);
  const [success, setSuccess] = useState<boolean>(false);
  const { mutate: forgotPassword } = useForgotPassword();

  const handleSubmit = async (values: any) => {
    setError(null);
    setSuccess(false);
    
    forgotPassword(values, {
      onSuccess: () => {
        setSuccess(true);
      },
      onError: (error) => {
        setError(error?.message || "An error occurred. Please try again.");
      }
    });
  };

  return (
    <AuthPage
      type="forgotPassword"
      title={
        <Space direction="vertical" size={0} style={{ textAlign: "center" }}>
          <Title level={3}>Forgot Password</Title>
          <Text type="secondary">Enter your email to reset your password</Text>
        </Space>
      }
      formProps={{
        onFinish: handleSubmit,
      }}
      renderContent={(content: React.ReactNode) => (
        <Space direction="vertical" style={{ width: "100%" }}>
          {error && (
            <Alert 
              message="Error" 
              description={error} 
              type="error" 
              showIcon 
            />
          )}
          {success && (
            <Alert 
              message="Success" 
              description="If your email is registered with us, you will receive password reset instructions." 
              type="success" 
              showIcon 
            />
          )}
          {content}
        </Space>
      )}
    />
  );
};
