import { AuthPage } from "@refinedev/antd";
import { Typography, Alert, Space } from "antd";
import { useState } from "react";
import { useLogin } from "@refinedev/core";

const { Title, Text } = Typography;

export const Login = () => {
  const [error, setError] = useState<string | null>(null);
  const { mutate: login } = useLogin();

  const handleSubmit = async (values: any) => {
    setError(null);
    
    login(values, {
      onError: (error) => {
        setError(error?.message || "An error occurred during login");
      }
    });
  };

  return (
    <AuthPage
      type="login"
      title={
        <Space direction="vertical" size={0} style={{ textAlign: "center" }}>
          <Title level={3}>Welcome to BYOP Platform</Title>
          <Text type="secondary">Login to manage your deployments</Text>
        </Space>
      }
      formProps={{
        onFinish: handleSubmit,
      }}
      renderContent={(content: React.ReactNode) => (
        <Space direction="vertical" style={{ width: "100%" }}>
          {error && (
            <Alert 
              message="Login Failed" 
              description={error} 
              type="error" 
              showIcon 
            />
          )}
          {content}
        </Space>
      )}
    />
  );
};
