import React from 'react';
import { Card, List, Typography, Tag, Button, Space, Empty } from 'antd';
import { BellOutlined, CheckOutlined, DeleteOutlined } from '@ant-design/icons';

const { Title, Text } = Typography;

// Mock notification data
const mockNotifications = [
  {
    id: '1',
    title: 'New client deployment',
    description: 'Acme Corp SAAS deployment is now active',
    time: '5 minutes ago',
    type: 'success',
    read: false,
  },
  {
    id: '2',
    title: 'Alert: High CPU Usage',
    description: 'Client XYZ experiencing high resource utilization',
    time: '20 minutes ago',
    type: 'warning',
    read: false,
  },
  {
    id: '3',
    title: 'Deployment Completed',
    description: 'Production deployment for Client ABC has finished successfully',
    time: '1 hour ago',
    type: 'success',
    read: true,
  },
  {
    id: '4',
    title: 'System Maintenance',
    description: 'Scheduled maintenance window will begin at 2:00 AM UTC',
    time: '2 hours ago',
    type: 'info',
    read: true,
  },
];

export const Notifications = () => {
  const getTypeColor = (type: string) => {
    const colorMap: Record<string, string> = {
      success: 'green',
      warning: 'orange',
      error: 'red',
      info: 'blue',
    };
    return colorMap[type] || 'default';
  };

  const handleMarkAsRead = (id: string) => {
    console.log('Mark as read:', id);
    // Here you would typically call an API to mark notification as read
  };

  const handleDelete = (id: string) => {
    console.log('Delete notification:', id);
    // Here you would typically call an API to delete notification
  };

  const handleMarkAllAsRead = () => {
    console.log('Mark all as read');
    // Here you would typically call an API to mark all notifications as read
  };

  return (
    <div style={{ padding: '24px' }}>
      <div style={{ 
        display: "flex", 
        justifyContent: "space-between", 
        alignItems: "center", 
        marginBottom: 24 
      }}>
        <Title level={2} style={{ margin: 0 }}>
          <BellOutlined style={{ marginRight: 8 }} />
          Notifications
        </Title>
        <Button onClick={handleMarkAllAsRead}>
          Mark All as Read
        </Button>
      </div>

      <Card>
        {mockNotifications.length > 0 ? (
          <List
            dataSource={mockNotifications}
            renderItem={(item) => (
              <List.Item
                style={{
                  backgroundColor: item.read ? 'transparent' : '#f6f6f6',
                  padding: '16px',
                  borderRadius: 8,
                  marginBottom: 8,
                }}
                actions={[
                  !item.read && (
                    <Button
                      type="text"
                      size="small"
                      icon={<CheckOutlined />}
                      onClick={() => handleMarkAsRead(item.id)}
                    >
                      Mark as Read
                    </Button>
                  ),
                  <Button
                    type="text"
                    size="small"
                    danger
                    icon={<DeleteOutlined />}
                    onClick={() => handleDelete(item.id)}
                  >
                    Delete
                  </Button>,
                ].filter(Boolean)}
              >
                <List.Item.Meta
                  title={
                    <Space>
                      <Text strong={!item.read}>{item.title}</Text>
                      <Tag color={getTypeColor(item.type)}>{item.type.toUpperCase()}</Tag>
                      {!item.read && <Tag color="red">NEW</Tag>}
                    </Space>
                  }
                  description={
                    <div>
                      <div style={{ marginBottom: 4 }}>{item.description}</div>
                      <Text type="secondary" style={{ fontSize: 12 }}>
                        {item.time}
                      </Text>
                    </div>
                  }
                />
              </List.Item>
            )}
          />
        ) : (
          <Empty 
            image={Empty.PRESENTED_IMAGE_SIMPLE}
            description="No notifications"
          />
        )}
      </Card>
    </div>
  );
};
