import React from 'react';
import { Card, Descriptions, Typography, Avatar, Button, Space } from 'antd';
import { useGetIdentity } from '@refinedev/core';
import { UserOutlined, EditOutlined } from '@ant-design/icons';

const { Title } = Typography;

type IUser = {
  id: number;
  name: string;
  email: string;
  avatar: string;
  role?: string;
};

export const Profile = () => {
  const { data: user } = useGetIdentity<IUser>();

  return (
    <div style={{ padding: '24px' }}>
      <div style={{ 
        display: "flex", 
        justifyContent: "space-between", 
        alignItems: "center", 
        marginBottom: 24 
      }}>
        <Title level={2} style={{ margin: 0 }}>
          Profile
        </Title>
        <Button type="primary" icon={<EditOutlined />}>
          Edit Profile
        </Button>
      </div>

      <Card style={{ maxWidth: 600 }}>
        <div style={{ textAlign: 'center', marginBottom: 24 }}>
          {user?.avatar ? (
            <Avatar size={80} src={user?.avatar} alt={user?.name} />
          ) : (
            <Avatar size={80} icon={<UserOutlined />} />
          )}
          <Title level={3} style={{ marginTop: 16, marginBottom: 8 }}>
            {user?.name || 'User'}
          </Title>
        </div>

        <Descriptions column={1} bordered>
          <Descriptions.Item label="User ID">
            {user?.id || 'N/A'}
          </Descriptions.Item>
          <Descriptions.Item label="Name">
            {user?.name || 'N/A'}
          </Descriptions.Item>
          <Descriptions.Item label="Email">
            {user?.email || 'N/A'}
          </Descriptions.Item>
          <Descriptions.Item label="Role">
            {user?.role || 'User'}
          </Descriptions.Item>
        </Descriptions>
      </Card>
    </div>
  );
};
