import { Form, Input, Button, Typography, Alert, Card } from "antd";
import { useState } from "react";
import { useRegister, useLink } from "@refinedev/core";
import { UserOutlined, MailOutlined, LockOutlined } from '@ant-design/icons';

const { Title, Text } = Typography;

export const Register = () => {
  const [error, setError] = useState<string | null>(null);
  const { mutate: register } = useRegister();
  const Link = useLink();
  
  const handleSubmit = (values: any) => {
    setError(null);
    console.log("Registration form data:", values);
    
    register(values, {
      onSuccess: () => {
        console.log("Registration successful");
      },
      onError: (error) => {
        console.error("Registration error:", error);
        setError(error?.message || "An error occurred during registration");
      }
    });
  };

  return (
    <div style={{ 
      display: "flex", 
      flexDirection: "column",
      alignItems: "center",
      justifyContent: "center",
      minHeight: "100vh",
      background: "#f0f2f5" // Match the login page background
    }}>
      <Card
        style={{
          width: 400,
          maxWidth: "90%",
          padding: "24px 0",
          boxShadow: "0 4px 12px rgba(0, 0, 0, 0.08)"
        }}
      >
        <div style={{ textAlign: "center", marginBottom: 24 }}>
          <Title level={3}>Join BYOP Platform</Title>
          <Text type="secondary">Create an account to get started</Text>
        </div>

        {error && (
          <Alert 
            style={{ marginBottom: 24, marginLeft: 24, marginRight: 24 }}
            message="Registration Failed" 
            description={error} 
            type="error" 
            showIcon 
          />
        )}

        <Form
          name="register-form"
          initialValues={{ username: "", email: "", password: "" }}
          onFinish={handleSubmit}
          layout="vertical"
          style={{ padding: "0 24px" }}
        >
          <Form.Item
            name="username"
            label="Username"
            rules={[{ required: true, message: 'Please input your username!' }]}
          >
            <Input 
              prefix={<UserOutlined />} 
              size="large" 
              placeholder="Username" 
            />
          </Form.Item>

          <Form.Item
            name="email"
            label="Email"
            rules={[
              { required: true, message: 'Please input your email!' },
              { type: 'email', message: 'Please enter a valid email!' }
            ]}
          >
            <Input 
              prefix={<MailOutlined />} 
              size="large" 
              placeholder="Email" 
            />
          </Form.Item>

          <Form.Item
            name="password"
            label="Password"
            rules={[{ required: true, message: 'Please input your password!' }]}
          >
            <Input.Password 
              prefix={<LockOutlined />} 
              size="large" 
              placeholder="Password" 
              autoComplete="new-password"
            />
          </Form.Item>

          <Form.Item>
            <Button 
              type="primary" 
              htmlType="submit" 
              size="large" 
              block
            >
              Sign Up
            </Button>
          </Form.Item>
          
          <div style={{ textAlign: "center" }}>
            <Text type="secondary">
              Already have an account?{" "}
              <Link to="/login">
                Sign in
              </Link>
            </Text>
          </div>
        </Form>
      </Card>
    </div>
  );
};