import React from 'react';
import { Card, Form, Input, Button, Switch, Select, Typography, Space, Divider } from 'antd';
import { SaveOutlined, UserOutlined, BellOutlined, LockOutlined } from '@ant-design/icons';

const { Title, Text } = Typography;
const { Option } = Select;

export const Settings = () => {
  const [form] = Form.useForm();

  const handleSave = (values: any) => {
    console.log('Settings saved:', values);
    // Here you would typically call an API to save settings
  };

  return (
    <div style={{ padding: '24px' }}>
      <div style={{ 
        display: "flex", 
        justifyContent: "space-between", 
        alignItems: "center", 
        marginBottom: 24 
      }}>
        <Title level={2} style={{ margin: 0 }}>
          Settings
        </Title>
      </div>

      <div style={{ maxWidth: 800 }}>
        <Form
          form={form}
          layout="vertical"
          onFinish={handleSave}
          initialValues={{
            notifications: true,
            theme: 'light',
            language: 'en',
            emailNotifications: true,
            deploymentAlerts: true,
          }}
        >
          {/* Account Settings */}
          <Card 
            title={
              <Space>
                <UserOutlined />
                <Text strong>Account Settings</Text>
              </Space>
            }
            style={{ marginBottom: 24 }}
          >
            <Form.Item
              label="Display Name"
              name="displayName"
            >
              <Input placeholder="Enter your display name" />
            </Form.Item>
            
            <Form.Item
              label="Email"
              name="email"
            >
              <Input placeholder="Enter your email" />
            </Form.Item>
            
            <Form.Item
              label="Language"
              name="language"
            >
              <Select>
                <Option value="en">English</Option>
                <Option value="fr">French</Option>
                <Option value="es">Spanish</Option>
              </Select>
            </Form.Item>
          </Card>

          {/* Notification Settings */}
          <Card 
            title={
              <Space>
                <BellOutlined />
                <Text strong>Notification Settings</Text>
              </Space>
            }
            style={{ marginBottom: 24 }}
          >
            <Form.Item
              label="Email Notifications"
              name="emailNotifications"
              valuePropName="checked"
            >
              <Switch />
            </Form.Item>
            
            <Form.Item
              label="Deployment Alerts"
              name="deploymentAlerts"
              valuePropName="checked"
            >
              <Switch />
            </Form.Item>
            
            <Form.Item
              label="System Notifications"
              name="systemNotifications"
              valuePropName="checked"
            >
              <Switch />
            </Form.Item>
          </Card>

          {/* Security Settings */}
          <Card 
            title={
              <Space>
                <LockOutlined />
                <Text strong>Security</Text>
              </Space>
            }
            style={{ marginBottom: 24 }}
          >
            <Space direction="vertical" style={{ width: '100%' }}>
              <Button type="default">
                Change Password
              </Button>
              <Button type="default">
                Enable Two-Factor Authentication
              </Button>
              <Button type="default">
                Download Account Data
              </Button>
            </Space>
          </Card>

          {/* Save Button */}
          <Card>
            <Form.Item>
              <Button 
                type="primary" 
                htmlType="submit" 
                icon={<SaveOutlined />}
                size="large"
              >
                Save Settings
              </Button>
            </Form.Item>
          </Card>
        </Form>
      </div>
    </div>
  );
};
