/**
 * Simplified App data model
 */
export interface App {
    id: number;
    name: string;
    version: string;
    components: number[]; // Array of component IDs
    createdAt: string;
    updatedAt: string;
}

export interface ComponentConfig {
    id: string;
    name: string;
    version?: string;
    image?: string;
    ports?: number[];
    environment?: Record<string, string>;
    resources?: {
        cpu: string;
        memory: string;
        storage: string;
    };
    publicAccess?: boolean;
    serviceMesh?: boolean;
}

export interface NetworkPolicy {
    name: string;
    rules: Array<{
        from?: string[];
        to?: string[];
        ports?: number[];
    }>;
    sourceComponents?: string[];
    targetComponents?: string[];
    ports?: number[];
    protocols?: string[];
    priority?: number;
    action?: string;
}

export interface SecretConfig {
    name: string;
    type: 'env' | 'file' | 'volume' | 'key';
    data: Record<string, string>;
    mountPath?: string;
    source?: string;
}

export interface AppFormData {
    name: string;
    version: string;
    components: number[];
    config?: {
        components?: ComponentConfig[];
        networkPolicies?: NetworkPolicy[];
        secrets?: SecretConfig[];
        envVariables?: Record<string, string>;
    };
}
