/**
 * Blueprint data model that matches the Golang backend implementation
 */

import { Deployment } from './deployment';
export interface Blueprint {
  id: number;
  name: string;
  description: string;
  version: string;

  // Configuration
  config: BlueprintConfig;

  // Metadata
  createdAt: string;
  updatedAt: string;
  createdBy: number;

  // Relationships
  deployments?: Deployment[];
}

export interface BlueprintConfig {
  components: ComponentConfig[];
  networkPolicies: NetworkPolicy[];
  envVariables?: Record<string, string>;
  secrets?: SecretConfig[];
}

export interface ComponentConfig {
  id: number;
  name: string;
  exposedPorts?: number[];
  publicAccess: boolean;
  resources: ResourceConfig;
  autoscaling?: AutoscalingConfig;
  envOverrides?: Record<string, string>;
  serviceMesh: boolean;
}

export interface ResourceConfig {
  cpu: string;
  memory: string;
  storage: string;
}

export interface AutoscalingConfig {
  enabled: boolean;
  minReplicas: number;
  maxReplicas: number;
  cpuThreshold: number;
  metric: string;
}

export interface NetworkPolicy {
  name: string;
  sourceComponents: string[];
  targetComponents: string[];
  ports: number[];
  protocols: string[];
  priority: number;
  action: 'allow' | 'deny';
}

export interface SecretConfig {
  name: string;
  type: 'env' | 'file' | 'key';
  value?: string;
  source?: string;
  mountPath?: string;
}

export interface BlueprintFormData {
  name: string;
  description: string;
  version: string;
  config: {
    components: ComponentConfig[];
    networkPolicies: NetworkPolicy[];
    envVariables?: Record<string, string>;
    secrets?: SecretConfig[];
  };
}
