/**
 * User data model that matches authentication and permission requirements
 * Note: Password is intentionally not included in this interface for security
 */
export interface User {
  id: number;
  username: string;
  email: string;
  role: UserRole;
  clientId?: number; // Only present for client users
  isActive: boolean;
  lastLogin?: string;
  preferences: UserPreferences;
  permissions: Permission[];

  createdAt: string;
  updatedAt: string;
}

export type UserRole =
  | 'system_admin'      // Full system access
  | 'system_manager'    // Platform management but limited admin access
  | 'support'           // Support staff
  | 'developer'         // Internal developer
  | 'client_manager'    // Limited to their own client resources
  | 'client_user';      // Very limited permissions

export interface Permission {
  resource: string;
  action: PermissionAction;
  constraints?: Record<string, any>;
}

export type PermissionAction =
  | 'create'
  | 'read'
  | 'update'
  | 'delete'
  | 'deploy';

export interface UserPreferences {
  theme: string;
  notifications: boolean;
  dashboardLayout?: Record<string, any>;
}

/**
 * User form data - what's accepted when creating/updating users
 * Password only included in creation/password change operations
 */
export interface UserFormData {
  username: string;
  email: string;
  role: UserRole;
  clientId?: string;
  isActive: boolean;
  password?: string; // Only for creation/password reset
  permissions?: Permission[];
}